@@ -6,11 +6,13 @@ use feature qw /postderef signatures/;
 package Vote::Count::Matrix;
 use Moose;
 
-with 'Vote::Count::TieBreaker',
+with 
+  'Vote::Count::Common',
   'Vote::Count::Approval',
   'Vote::Count::Borda',
   'Vote::Count::Log',
   'Vote::Count::Score',
+  'Vote::Count::TieBreaker',
   ;
 
 use Vote::Count::RankCount;
@@ -22,18 +24,17 @@ use Sort::Hash;
 use Storable 3.15 'dclone';
 
 # use Try::Tiny;
-#use Data::Printer;
 #use Data::Dumper;
 
 use YAML::XS;
 
-our $VERSION='1.06';
+our $VERSION='1.07';
 
 =head1 NAME
 
 Vote::Count::Matrix
 
-=head1 VERSION 1.06
+=head1 VERSION 1.07
 
 =cut
 
@@ -45,13 +46,6 @@ has BallotSet => (
   isa      => 'HashRef',
 );
 
-has Active => (
-  is      => 'rw',
-  isa     => 'HashRef',
-  builder => 'Vote::Count::Matrix::_buildActive',
-  lazy    => 1,
-);
-
 has TieBreakMethod => (
   is       => 'rw',
   isa      => 'Str',
@@ -59,10 +53,6 @@ has TieBreakMethod => (
   default  => 'none',
 );
 
-sub _buildActive ( $self ) {
-  return dclone $self->BallotSet->{'choices'};
-}
-
 sub _untie ( $I, $A, $B ) {
   my @untie = $I->TieBreaker( $I->TieBreakMethod(), $I->Active(), $A, $B );
   return $untie[0] if ( scalar(@untie) == 1 );
@@ -250,7 +240,8 @@ sub CondorcetWinner( $self ) {
 sub GreatestLoss ( $self, $A ) {
   my $bigloss = 0;
 GREATESTLOSSLOOP:
-  for my $B ( keys $self->Active()->%* ) {
+  for my $B ( $self->GetActiveList() ) {
+  # for my $B ( keys $self->Active()->%* ) {
     next GREATESTLOSSLOOP if $B eq $A;
     my %result = $self->{'Matrix'}{$A}{$B}->%*;
 # warn "$A : $B loser $result{'loser'} : margin $result{'margin'} $A: $result{$A} $B: $result{$B}";
